<?php

namespace Drupal\config_enforce_devel;

/**
 * Provides integration with config_devel.
 */
class ConfigDevelHelper {

  /**
   * Provide Config Devel module with configs to read from disk.
   *
   * @see hook_config_devel_auto_import()
   */
  public static function autoImport() {
    $auto_import = [];
    foreach ((new EnforcedConfigCollection())->getEnforcedConfigs() as $config_name => $settings) {
      $auto_import[$config_name] = [
        'filename' => $settings['config_file_path'],
        'hash' => $settings['hash'],
      ];
    }
    return $auto_import;
  }

  /**
   * Provide Config Devel module with config files to write to disk.
   *
   * @see hook_config_devel_auto_export()
   */
  public static function autoExport() {
    $auto_export = [];
    foreach ((new EnforcedConfigCollection())->getEnforcedConfigs() as $config_name => $settings) {
      $auto_export[] = $settings['config_file_path'];
    }
    return $auto_export;
  }

  /**
   * Save hashes of auto-imported config files.
   *
   * @see config_enforce_devel_config_devel_post_auto_import()
   */
  public static function postAutoImport(array $auto_import) {
    $registries = (new TargetModuleCollection())->getRegistryConfigNames();
    $enforced_configs = (new EnforcedConfigCollection())->getEnforcedConfigs();
    $hashes = [];
    foreach ($auto_import as $config_name => $results) {
      // Skip registry configs, since their hashes are hard-coded.
      // @see EnforcedConfigRegistry::updateEnforcedConfigs().
      if (in_array($config_name, $registries)) continue;

      // Skip configs whose hashes haven't changed.
      if ($results['hash'] == $enforced_configs[$config_name]['hash']) continue;

      $hashes[$config_name] = ['hash' => $results['hash']];
    }
    (new EnforcedConfigCollection())->updateEnforcedConfigs($hashes);
  }

}
